#include <avr/io.h>
#include <util/delay.h>
#include "i2c.h"
#include "lcd.h"
#include "keyb.h"
#include "MCP79410.h"

const char * WeekDays[] = {"  ", "pn", "wt", "sr", "cz", "pt", "so", "nd"};
	
void setDateTime();
uint8_t getWeekDay(DateTime * dateTime);

int main(void) {
	i2cInit();
	keybInit();
	lcdInit();
	lcdInitPrintf();
	while(1){
		DateTime dateTime;
		rtcReadDateTime(&dateTime);
		lcdGotoXY(0, 0);
		printf("%02d:%02d:%02d", dateTime.hours, dateTime.minutes, dateTime.seconds);
		lcdGotoXY(0, 1);
		printf("%02d-%02d-%4d", dateTime.dayOfMonth, dateTime.month, dateTime.year);
		printf(" %s", WeekDays[dateTime.dayOfWeek]);
		if (readKeyboard()) {
			while(readKeyboard());
			setDateTime();
		}
	}
}

void setDateTime() {
	//wcz kursor
	lcdWriteCommand(LCD_COMMAND_ON_OFF | LCD_PARAM_ON_OFF_CURSOR | LCD_PARAM_ON_OFF_DISPLAY);
	//wczytaj czas
	lcdGotoXY(0, 0);
	printf("  :  :  ");
	lcdGotoXY(0, 0);
	const uint8_t timeFieldsSizes[] = {2, 2, 2};
	uint16_t time[3];
	readSeparatedNumbers(timeFieldsSizes, 3, time);
	//wczytaj dat
	lcdGotoXY(0, 1);
	printf("  -  -    ");
	lcdGotoXY(0, 1);
	const uint8_t dateFieldsSizes[] = {2, 2, 4};
	uint16_t date[3];
	readSeparatedNumbers(dateFieldsSizes, 3, date);
	DateTime newDateTime;
	newDateTime.hours = time[0];
	newDateTime.minutes = time[1];
	newDateTime.seconds = time[2];
	newDateTime.dayOfMonth = date[0];
	newDateTime.month = date[1];
	newDateTime.year = date[2];
	newDateTime.dayOfWeek = getWeekDay(&newDateTime);
	//zapisz nowy czas i dat
	rtcWriteDateTime(&newDateTime);
	//wycz kursor
	lcdWriteCommand(LCD_COMMAND_ON_OFF | LCD_PARAM_ON_OFF_DISPLAY);
}

uint8_t getWeekDay(DateTime * dateTime) {
	int d = dateTime->dayOfMonth;
	int m = dateTime->month;
	int y = dateTime->year;
	uint8_t weekday  = (d += m < 3 ? y-- : y - 2, 23*m/9 + d + 4 + y/4- y/100 + y/400)%7;
	if (!weekday) weekday = 7;
	return weekday;
}